@@ -1,20 +1,19 @@
-import {CommonModule} from "@angular/common";
-import {FormsModule} from "@angular/forms";
-import {NgModule} from "@angular/core";
-import {Routes, RouterModule} from "@angular/router";
-
+import { CommonModule } from "@angular/common"
+import { FormsModule } from "@angular/forms"
+import { NgModule } from "@angular/core"
+import { Routes, RouterModule } from "@angular/router"
 
 // Import our components
-import {ChatComponent} from "./chat.component";
+import { ChatComponent } from "./chat.component"
 
 // Define the routes for this Angular module
 export const pluginRoutes: Routes = [
     {
-        path: '',
+        path: "",
         component: ChatComponent
     }
 
-];
+]
 
 // Define the module
 @NgModule({
